![Unit Tests](https://github.com/hile/pathlib-tree/actions/workflows/unittest.yml/badge.svg)
![Style Checks](https://github.com/hile/pathlib-tree/actions/workflows/lint.yml/badge.svg)

# Tree extension for pathlib.Path

This module implements an extensible tree-like object `pathlib_tree.Tree` that can be iterated
and subclassed to use for various filesystem tree processing tasks.
